__quantum__qis__r__adj

Function __quantum__qis__r__adj 

#[unsafe(no_mangle)]
pub extern "C" fn __quantum__qis__r__adj( pauli: Pauli, theta: c_double, qubit: *mut c_void, )
QIR API for applying an adjoint rotation about the given Pauli axis with the given angle and qubit.