__quantum__qis__read_result__body

Function __quantum__qis__read_result__body 

#[unsafe(no_mangle)]
pub extern "C" fn __quantum__qis__read_result__body( result: *mut c_void, ) -> bool
QIR API that reads the Boolean value corresponding to the given result identifier, where true indicates a |1⟩ state and false indicates a |0⟩ state.