__quantum__qis__s__ctladj

Function __quantum__qis__s__ctladj 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__qis__s__ctladj( ctls: *const QirArray, qubit: *mut c_void, )
QIR API for performing the multicontrolled Adjoint S gate with the given qubits.

Safety

This function should only be called with arrays and tuples created by the QIR runtime library.