__quantum__qis__z__ctl

Function __quantum__qis__z__ctl 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__qis__z__ctl( ctls: *const QirArray, qubit: *mut c_void, )
QIR API for performing the multicontrolled Z gate with the given qubits.

Safety

This function should only be called with arrays and tuples created by the QIR runtime library.