__quantum__rt__array_record_output

Function __quantum__rt__array_record_output 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__rt__array_record_output( val: i64, tag: *mut i8, )
Inserts a marker in the generated output that indicates the start of an array and how many array elements it has. The second parameter defines a string label for the array. Depending on the output schema, the label is included in the output or omitted.