__quantum__rt__qubit_allocate_array

Function __quantum__rt__qubit_allocate_array 

#[unsafe(no_mangle)]
pub extern "C" fn __quantum__rt__qubit_allocate_array( size: u64, ) -> *const QirArray
QIR API for allocating the given number of qubits in the simulation, returning them as a runtime managed array.

Panics

This function will panic if the requested array size is too large to be described with the system pointer size.