__quantum__rt__qubit_release_array

Function __quantum__rt__qubit_release_array 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__rt__qubit_release_array( arr: *const QirArray, )
QIR API for releasing the given runtime managed qubit array.

Safety

This function should only be called with arrays created by __quantum__rt__qubit_allocate_array.