__quantum__rt__qubit_to_string

Function __quantum__rt__qubit_to_string 

#[unsafe(no_mangle)]
pub extern "C" fn __quantum__rt__qubit_to_string( qubit: *mut c_void, ) -> *const CString
QIR API for getting the string interpretation of a qubit identifier.

Panics

This function will panic if memory cannot be allocated for the underyling string.