__quantum__rt__read_result

Function __quantum__rt__read_result 

#[unsafe(no_mangle)]
pub extern "C" fn __quantum__rt__read_result( result: *mut c_void, ) -> bool
QIR API that reads the Boolean value corresponding to the given result identifier, where true indicates a |1⟩ state and false indicates a |0⟩ state.