__quantum__rt__result_record_output

Function __quantum__rt__result_record_output 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __quantum__rt__result_record_output( result: *mut c_void, tag: *mut c_char, )
QIR API for recording the given result into the program output.

Safety

This function will panic if the tag cannot be written to the output buffer.