__quantum__rt__write_result

Function __quantum__rt__write_result 

#[unsafe(no_mangle)]
pub extern "C" fn __quantum__rt__write_result( value: bool, result: *mut c_void, )
QIR API that writes the given Boolean value to the given result identifier, overwriting any previous value stored there.