qubit_is_zero

Function qubit_is_zero 

pub fn qubit_is_zero(qubit: *mut c_void) -> bool
Rust API for checking internal simulator state and returning true only if the given qubit is in exactly the |0⟩ state.